<?php
/**
 * Plugin Name: Product Filters for WooCommerce
 * Plugin URI: https://woocommerce.com/products/product-filters/
 * Description: This is a tool to create product filters that make the process of finding products in your store simple and fast.
 * Version: 1.4.36
 * Author: WooCommerce
 * Author URI: https://woocommerce.com/
 * Text Domain: woocommerce-product-filters
 * Domain Path: /languages
 * Requires Plugins: woocommerce
 * Tested up to: 6.7
 * WC tested up to: 9.6
 * WC requires at least: 6.0
 *
 * Copyright: © 2025 WooCommerce
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 *
 * Woo: 3546049:762bae993b965c395f0bf27fe08dd4cd
 */

require __DIR__ . '/vendor/autoload.php';

use Automattic\WooCommerce\Grow\Tools\CompatChecker\v0_0_1\Checker;
use Automattic\WooCommerce\Utilities\FeaturesUtil;
use WooCommerce_Product_Filter_Plugin\Autoloader;
use WooCommerce_Product_Filter_Plugin\Plugin;

if ( ! defined( 'WPINC' ) ) {
	die();
}

define( 'WC_PRODUCT_FILTER_VERSION', '1.4.36' ); // WRCS: DEFINED_VERSION.

define( 'WC_PRODUCT_FILTER_INDEX', 'woocommerce-product-filters' );

define( 'WC_PRODUCT_FILTER_PLUGIN_ACTIVATED_OPTION', 'wcpf-activated-plugin' );

define( 'WC_PRODUCT_FILTER_PLUGIN_FILE', __FILE__ );

// HPOS compatibility declaration.
add_action(
	'before_woocommerce_init',
	function () {
		if ( class_exists( FeaturesUtil::class ) ) {
			FeaturesUtil::declare_compatibility( 'custom_order_tables', plugin_basename( __FILE__ ) );
		}
	}
);

add_filter( 'woocommerce_translations_updates_for_woocommerce-product-filters', '__return_true' );

add_action( 'plugins_loaded', 'wcpf_plugin_init' );

register_activation_hook( WC_PRODUCT_FILTER_PLUGIN_FILE, 'wcpf_plugin_activate' );

/**
 * Do stuff on plugin activation.
 *
 * @see https://developer.wordpress.org/reference/functions/register_activation_hook/#process-flow
 */
function wcpf_plugin_activate() {
	add_option( WC_PRODUCT_FILTER_PLUGIN_ACTIVATED_OPTION, WC_PRODUCT_FILTER_INDEX );
}

/**
 * Initialize the plugin.
 */
function wcpf_plugin_init() {
	if ( ! Checker::instance()->is_compatible( __FILE__, WC_PRODUCT_FILTER_VERSION ) ) {
		return;
	}

	// Load
	require_once __DIR__ . '/includes/class-autoloader.php';
	require_once __DIR__ . '/includes/functions.php';

	// Register the autoloader.
	( new Autoloader() )->register();

	// The codebase still requires a global to access the plugin instance.
	$GLOBALS['wcpf_plugin'] = new Plugin();
	$GLOBALS['wcpf_plugin']->init();
}
